@@ -1,5 +1,6 @@
 #!/bin/sh
-# Copyright (C) 2002  Slackware Linux, Inc.
+# Copyright (C) 2002, 2005  Slackware Linux, Inc.
+# Copyright 2005, 2006  Patrick J. Volkerding, Sebeka, Minnesota, USA
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -16,6 +17,7 @@
 # If we're on a running system we have to handle this _very_ carefully.  :-)
 # The tricks involved here get trickier every time...
 
+# Install linuxthreads glibc libraries:
 if [ -x /sbin/ldconfig -a -d /lib/incoming ]; then # swap on the fly
   # First create copies of the incoming libraries:
   ( cd lib/incoming
@@ -43,9 +45,41 @@ else # no ldconfig?  Good, it's safe to just jam it on home (and make links belo
     done
   )
 fi
-
 # Now, get rid of the temporary directory:
 rm -rf lib/incoming
+# Done installing linuxthreads glibc libraries.
+
+# Install NPTL glibc libraries:
+if [ -x /sbin/ldconfig -a -d /lib/tls/incoming ]; then # swap on the fly
+  # First create copies of the incoming libraries:
+  ( cd lib/tls/incoming
+    for file in * ; do
+      if [ ! -r ../${file}.incoming ]; then
+        cp -a $file ../${file}.incoming
+      fi
+    done
+  )
+  # Then switch to them all at once:
+  /sbin/ldconfig -l /lib/tls/*.incoming 2> /dev/null
+  # Finally, rename them and clean up:
+  ( cd lib/tls
+    for file in *.incoming ; do
+      rm -f `basename $file .incoming`
+      cp -a $file `basename $file .incoming`
+      /sbin/ldconfig -l `basename $file .incoming`
+      rm -f $file
+    done
+  )
+else # no ldconfig?  Good, it's safe to just jam it on home (and make links below):
+  ( cd lib/tls/incoming
+    for file in * ; do
+      cp -a $file ..
+    done
+  )
+fi
+# Now, get rid of the temporary directory:
+rm -rf lib/tls/incoming
+# Done installing NPTL glibc libraries.
 
 # Timezone stuff:
 if [ -L etc/localtime -a ! -r etc/localtime-copied-from ]; then
@@ -66,62 +100,111 @@ fi
 ( cd usr/share/zoneinfo ; rm -rf timeconfig )
 ( cd usr/share/zoneinfo ; ln -sf /usr/sbin/timeconfig timeconfig )
 
-# Handle nscd.conf config file:
+# Handle config files:
 config() {
   NEW="$1"
-  OLD="`dirname $NEW`/`basename $NEW .new`"
+  OLD="$(dirname $NEW)/$(basename $NEW .new)"
   # If there's no config file by that name, mv it over:
   if [ ! -r $OLD ]; then
     mv $NEW $OLD
-  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
+  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
     rm $NEW
   fi
   # Otherwise, we leave the .new copy for the admin to consider...
 }
 config etc/nscd.conf.new
+config etc/profile.d/glibc.csh.new
+config etc/profile.d/glibc.sh.new
+# Clearly you already decided this issue.  :-)
+rm -f etc/profile.d/glibc.csh.new
+rm -f etc/profile.d/glibc.sh.new
 
 # In case there's no ldconfig, make the links manually:
 if [ ! -x /sbin/ldconfig ]; then
+# linuxthreads:
 ( cd lib ; rm -rf libnss_nis.so.2 )
-( cd lib ; ln -sf libnss_nis-2.3.4.so libnss_nis.so.2 )
+( cd lib ; ln -sf libnss_nis-2.3.6.so libnss_nis.so.2 )
 ( cd lib ; rm -rf libm.so.6 )
-( cd lib ; ln -sf libm-2.3.4.so libm.so.6 )
+( cd lib ; ln -sf libm-2.3.6.so libm.so.6 )
 ( cd lib ; rm -rf libnss_files.so.2 )
-( cd lib ; ln -sf libnss_files-2.3.4.so libnss_files.so.2 )
+( cd lib ; ln -sf libnss_files-2.3.6.so libnss_files.so.2 )
 ( cd lib ; rm -rf libresolv.so.2 )
-( cd lib ; ln -sf libresolv-2.3.4.so libresolv.so.2 )
+( cd lib ; ln -sf libresolv-2.3.6.so libresolv.so.2 )
 ( cd lib ; rm -rf libnsl.so.1 )
-( cd lib ; ln -sf libnsl-2.3.4.so libnsl.so.1 )
+( cd lib ; ln -sf libnsl-2.3.6.so libnsl.so.1 )
 ( cd lib ; rm -rf libutil.so.1 )
-( cd lib ; ln -sf libutil-2.3.4.so libutil.so.1 )
+( cd lib ; ln -sf libutil-2.3.6.so libutil.so.1 )
 ( cd lib ; rm -rf libnss_compat.so.2 )
-( cd lib ; ln -sf libnss_compat-2.3.4.so libnss_compat.so.2 )
+( cd lib ; ln -sf libnss_compat-2.3.6.so libnss_compat.so.2 )
 ( cd lib ; rm -rf libthread_db.so.1 )
 ( cd lib ; ln -sf libthread_db-1.0.so libthread_db.so.1 )
 ( cd lib ; rm -rf libnss_hesiod.so.2 )
-( cd lib ; ln -sf libnss_hesiod-2.3.4.so libnss_hesiod.so.2 )
+( cd lib ; ln -sf libnss_hesiod-2.3.6.so libnss_hesiod.so.2 )
 ( cd lib ; rm -rf libanl.so.1 )
-( cd lib ; ln -sf libanl-2.3.4.so libanl.so.1 )
+( cd lib ; ln -sf libanl-2.3.6.so libanl.so.1 )
 ( cd lib ; rm -rf libcrypt.so.1 )
-( cd lib ; ln -sf libcrypt-2.3.4.so libcrypt.so.1 )
+( cd lib ; ln -sf libcrypt-2.3.6.so libcrypt.so.1 )
 ( cd lib ; rm -rf libBrokenLocale.so.1 )
-( cd lib ; ln -sf libBrokenLocale-2.3.4.so libBrokenLocale.so.1 )
+( cd lib ; ln -sf libBrokenLocale-2.3.6.so libBrokenLocale.so.1 )
 ( cd lib ; rm -rf ld-linux.so.2 )
-( cd lib ; ln -sf ld-2.3.4.so ld-linux.so.2 )
+( cd lib ; ln -sf ld-2.3.6.so ld-linux.so.2 )
 ( cd lib ; rm -rf libdl.so.2 )
-( cd lib ; ln -sf libdl-2.3.4.so libdl.so.2 )
+( cd lib ; ln -sf libdl-2.3.6.so libdl.so.2 )
 ( cd lib ; rm -rf libnss_dns.so.2 )
-( cd lib ; ln -sf libnss_dns-2.3.4.so libnss_dns.so.2 )
+( cd lib ; ln -sf libnss_dns-2.3.6.so libnss_dns.so.2 )
 ( cd lib ; rm -rf libpthread.so.0 )
 ( cd lib ; ln -sf libpthread-0.10.so libpthread.so.0 )
 ( cd lib ; rm -rf libnss_nisplus.so.2 )
-( cd lib ; ln -sf libnss_nisplus-2.3.4.so libnss_nisplus.so.2 )
+( cd lib ; ln -sf libnss_nisplus-2.3.6.so libnss_nisplus.so.2 )
 ( cd lib ; rm -rf libc.so.6 )
-( cd lib ; ln -sf libc-2.3.4.so libc.so.6 )
+( cd lib ; ln -sf libc-2.3.6.so libc.so.6 )
 ( cd lib ; rm -rf librt.so.1 )
-( cd lib ; ln -sf librt-2.3.4.so librt.so.1 )
+( cd lib ; ln -sf librt-2.3.6.so librt.so.1 )
+# NPTL:
+( cd lib/tls ; rm -rf libnss_nis.so.2 )
+( cd lib/tls ; ln -sf libnss_nis-2.3.6.so libnss_nis.so.2 )
+( cd lib/tls ; rm -rf libm.so.6 )
+( cd lib/tls ; ln -sf libm-2.3.6.so libm.so.6 )
+( cd lib/tls ; rm -rf libnss_files.so.2 )
+( cd lib/tls ; ln -sf libnss_files-2.3.6.so libnss_files.so.2 )
+( cd lib/tls ; rm -rf libresolv.so.2 )
+( cd lib/tls ; ln -sf libresolv-2.3.6.so libresolv.so.2 )
+( cd lib/tls ; rm -rf libnsl.so.1 )
+( cd lib/tls ; ln -sf libnsl-2.3.6.so libnsl.so.1 )
+( cd lib/tls ; rm -rf libutil.so.1 )
+( cd lib/tls ; ln -sf libutil-2.3.6.so libutil.so.1 )
+( cd lib/tls ; rm -rf libnss_compat.so.2 )
+( cd lib/tls ; ln -sf libnss_compat-2.3.6.so libnss_compat.so.2 )
+( cd lib/tls ; rm -rf libthread_db.so.1 )
+( cd lib/tls ; ln -sf libthread_db-1.0.so libthread_db.so.1 )
+( cd lib/tls ; rm -rf libnss_hesiod.so.2 )
+( cd lib/tls ; ln -sf libnss_hesiod-2.3.6.so libnss_hesiod.so.2 )
+( cd lib/tls ; rm -rf libanl.so.1 )
+( cd lib/tls ; ln -sf libanl-2.3.6.so libanl.so.1 )
+( cd lib/tls ; rm -rf libcrypt.so.1 )
+( cd lib/tls ; ln -sf libcrypt-2.3.6.so libcrypt.so.1 )
+( cd lib/tls ; rm -rf libBrokenLocale.so.1 )
+( cd lib/tls ; ln -sf libBrokenLocale-2.3.6.so libBrokenLocale.so.1 )
+( cd lib/tls ; rm -rf ld-linux.so.2 )
+( cd lib/tls ; ln -sf ld-2.3.6.so ld-linux.so.2 )
+( cd lib/tls ; rm -rf libdl.so.2 )
+( cd lib/tls ; ln -sf libdl-2.3.6.so libdl.so.2 )
+( cd lib/tls ; rm -rf libnss_dns.so.2 )
+( cd lib/tls ; ln -sf libnss_dns-2.3.6.so libnss_dns.so.2 )
+( cd lib/tls ; rm -rf libpthread.so.0 )
+( cd lib/tls ; ln -sf libpthread-2.3.6.so libpthread.so.0 )
+( cd lib/tls ; rm -rf libnss_nisplus.so.2 )
+( cd lib/tls ; ln -sf libnss_nisplus-2.3.6.so libnss_nisplus.so.2 )
+( cd lib/tls ; rm -rf libc.so.6 )
+( cd lib/tls ; ln -sf libc-2.3.6.so libc.so.6 )
+( cd lib/tls ; rm -rf librt.so.1 )
+( cd lib/tls ; ln -sf librt-2.3.6.so librt.so.1 )
 fi
 
+# This is needed for linking some NPTL stuff:
+( cd usr/lib/nptl ; rm -rf librt.so )
+( cd usr/lib/nptl ; ln -sf /lib/tls/librt-2.3.6.so librt.so )
+
 # More links:
 ( cd usr/lib ; rm -rf libnss_nisplus.so )
 ( cd usr/lib ; ln -sf ../../lib/libnss_nisplus.so.2 libnss_nisplus.so )
